#-*-coding:utf-8*-*
"""
Tests liés à la migration de variables
"""
from os.path import join, isfile
from creole.loader import creole_loader

CONFIG_DIR = '/usr/share/creole/tests/configs'
DICO_DIR = '/usr/share/eole/creole/dicos'

def _calc_config_file(test):
    """
    nom du fichier eol lié au test
    """
    return join(CONFIG_DIR, '{0}.eol'.format(test))

def _get_value(config, variable):
    """
    Retourne la valeur d'une variable "connue"
    """
    path = config.find_first(byname=variable, type_='path')
    return config.getattr(path, force_permissive=True)

def test_upgrade_hosts_from23():
    """
    Vérifie la migration des variables "activer_ajout_hosts"
    depuis une configuration 2.3 contenant des majuscules #11473
    """
    config = creole_loader(force_configeol=_calc_config_file('hosts23'))
    assert _get_value(config, 'activer_ajout_hosts') == 'oui'
    assert _get_value(config, 'nom_court_hosts') == ['min', 'maj']
    assert _get_value(config, 'nom_long_hosts') == ['min.min', 'maj.maj']

def test_upgrade_scribe_dmz():
    """
    Vérifie la migration de la variable "install_scribe_dmz"
    en fonction du remplissage des esclaves associées #11713
    ce test n'est pas compatible avec AmonEcole #11796
    """
    if isfile(join(DICO_DIR, '10_era.xml')) and not isfile(join(DICO_DIR, '50_amonecole.xml')):
        config = creole_loader(force_configeol=_calc_config_file('scribe_dmz_ok'))
        assert _get_value(config, 'install_scribe_dmz') == 'oui'
        config = creole_loader(force_configeol=_calc_config_file('scribe_dmz_ko'))
        assert _get_value(config, 'install_scribe_dmz') == 'non'

